//
// @author vay
// @email hxhvay@126.com
// @date 2020-07-06
//

import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:provider/provider.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/modules.dart';
import 'package:vaycore/src/modules/locale/vc_locale_delegate.dart';
import 'package:vaycore/utils.dart';

/// 应用主类基类
abstract class BaseApp extends StatelessWidget {
  /// Provider列表，提供全局的状态
  List<ChangeNotifierProvider> buildProviders() => [];

  /// 国际化支持列表
  Iterable<LocalizationsDelegate> getLocalizationsDelegates() => [];

  ThemeData buildThemeData() {
    return ThemeData(
      primarySwatch: VCTheme.getTheme(),
    );
  }

  Locale getLocale() {
    return VCLocale.getLocale();
  }

  String getTitle() {
    return null;
  }

  void onInit() {
    // 白色状态栏图标
    BarUtils.setStatusBarStyle(StatusBarStyle.dark);
  }

  @override
  Widget build(BuildContext context) {
    onInit();
    return MultiProvider(
      providers: [
        ChangeNotifierProvider.value(value: inject<VCTheme>()),
        ChangeNotifierProvider.value(value: inject<VCLocale>()),
        ...buildProviders(),
      ],
      child: Consumer2<VCTheme, VCLocale>(
        builder: (ctx, theme, locale, widget) => buildMaterialApp(),
      ),
    );
  }

  Widget buildHome();

  bool get hasTextScaleDisable => true;

  MaterialApp buildMaterialApp() {
    return MaterialApp(
      theme: buildThemeData(),
      locale: getLocale(),
      title: getTitle() ?? "",
      home: this.hasTextScaleDisable
          ? WidgetUtils.textScaleDisable(buildHome())
          : buildHome(),
      localizationsDelegates: [
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
        VCLocaleDelegate.delegate,
        ...getLocalizationsDelegates(),
      ],
      supportedLocales: VCLocale.supportLocales,
      localeResolutionCallback: VCLocale.localeResolutionCallback,
    );
  }
}
