//
// @author vay
// @email hxhvay@126.com
// @date 2020-07-04
//

import 'package:flutter/material.dart';
import 'package:vaycore/modules.dart';
import 'package:vaycore/mvvm.dart';

abstract class BaseTabNavigatorPage extends BaseStatefulPage<VoidProvider> {
  /// 导航对应的页面
  List<Widget> get pages;

  /// 底部导航栏Items
  List<BottomNavigationBarItem> get bottomItems;

  /// 默认显示的颜色
  Color get defaultColor => Colors.grey;

  /// 选中的颜色
  Color get activeColor => VCTheme.getTheme();

  /// 默认显示的tab
  int get defaultTabIndex => 0;

  /// 默认文字大小
  double get defaultFontSize => 12;

  /// 选中的文字大小
  double get activeFontSize => 12;

  @override
  BaseState<BaseStatefulPage<BaseProvider>, BaseProvider> buildState() =>
      _TabNavigatorState();
}

class _TabNavigatorState extends BaseState<BaseTabNavigatorPage, VoidProvider> {
  PageController _controller;
  int _tabIndex;

  @override
  void initState() {
    _tabIndex = widget.defaultTabIndex;
    _controller = PageController(initialPage: _tabIndex);
    super.initState();
  }

  @override
  void dispose() {
    _controller?.dispose();
    super.dispose();
  }

  @override
  Widget buildContent(BuildContext context) {
    return Scaffold(
      backgroundColor: Color(0xFFF5F2F2),
      body: PageView(
        controller: _controller,
        onPageChanged: (index) {
          setState(() {
            _tabIndex = index;
          });
        },
        children: widget.pages,
        physics: NeverScrollableScrollPhysics(),
      ),
      bottomNavigationBar: BottomNavigationBar(
        unselectedItemColor: widget.defaultColor,
        selectedItemColor: widget.activeColor,
        unselectedFontSize: widget.defaultFontSize,
        selectedFontSize: widget.activeFontSize,
        type: BottomNavigationBarType.fixed,
        currentIndex: _tabIndex,
        onTap: (index) {
          _controller.jumpToPage(index);
          _tabIndex = index;
        },
        items: widget.bottomItems,
      ),
    );
  }
}
