//
// @author vay
// @email hxhvay@126.com
// @date 2020-07-07
//

import 'package:flutter/material.dart';
import 'package:vaycore/modules.dart';
import 'package:vaycore/utils.dart';

/// 国际化业务接口
abstract class IVCLocaleHolder<T> extends IProfileComponent<String> {
  @override
  onInit() {}

  /// 支持的语言列表（第一个元素为默认语言）
  List<Locale> get supportLocales;

  /// 语言对应的数据
  Map<String, Map<T, String>> get localizedValues;

  /// 读取保存的语言
  Locale readLocale() {
    if (data == null) {
      return supportLocales.first;
    }
    var t = data.split("_");
    return Locale(t[0], t[1]);
  }

  /// 保存新配置的语言
  saveLocale(Locale locale) {
    if (locale == null) {
      return;
    }
    data = "${locale.languageCode}_${locale.countryCode}";
  }

  /// 获取当前配置的语言对应的资源表，如果找不到ID，则返回默认的资源表
  Map<T, String> getLocalizedValueById(T ids) {
    Map<T, String> value = localizedValues[readLocale().languageCode];
    if (value == null || !value.containsKey(ids)) {
      value = localizedValues[supportLocales.first.languageCode];
    }
    return value;
  }

  /// 获取国际化字符串
  String getString(T ids, [List<dynamic> params]) {
    if (this.readLocale() == null) {
      return "${ids.runtimeType}";
    }
    Map<T, String> value = getLocalizedValueById(ids);
    if (value == null || !value.containsKey(ids)) {
      return "${ids.runtimeType}";
    }
    if (params == null || params.isEmpty) {
      return value[ids];
    }
    return StringUtils.format(value[ids], params);
  }
}
