//
// @author vay
// @email hxhvay@126.com
// @date 2020-07-06
//

import 'package:flutter/material.dart';
import 'package:vaycore/core.dart';
import 'package:vaycore/dartin.dart';
import 'package:vaycore/modules.dart';
import 'package:vaycore/vaycore.dart';

/// 主题状态
class VCTheme extends VCComponent {
  /// 默认支持的语言列表
  static const List<ColorSwatch> DEFAULT_SUPPORT_THEMES = [
    Colors.lightBlue,
    Colors.lightGreen,
    Colors.red,
  ];

  static VCTheme get _instance => inject();

  /// 主题业务处理
  IVCThemeHolder _themeHolder;

  @override
  onInit() {
    _themeHolder = core.engine.buildThemeHolder();
  }

  /// 获取主题
  static ColorSwatch getTheme() {
    if (_instance._themeHolder == null) {
      return Colors.lightBlue;
    }
    return _instance._themeHolder.readTheme();
  }

  /// 设置主题
  static setTheme(ColorSwatch color) {
    if (_instance._themeHolder == null) {
      return;
    }
    _instance._themeHolder.saveTheme(color);
    _instance.notifyListeners();
  }

  /// 获取支持的主题列表
  static List<ColorSwatch> get supportThemes {
    if (_instance._themeHolder == null) {
      return DEFAULT_SUPPORT_THEMES;
    }
    return _instance._themeHolder.themes;
  }
}
