//
// @author vay
// @email hxhvay@126.com
// @date 2020-06-06
//

import 'package:vaycore/http.dart';

/// Http工具类
class HttpUtils {
  /// 不允许实例化
  HttpUtils._();

  /// 网络请求实例
  static final NetRequest _request = NetRequest(
    adapter: DefaultAdapter(),
    interceptors: [_netCache],
  );

  /// 网络缓存
  static final NetCache _netCache = NetCache();

  static Future<HttpResult> request(
    String url, {
    HttpMethod method = HttpMethod.GET,
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int timeout = 15000,
    String contentType = "application/json; charset=utf-8",
    bool refreshCache = false,
    bool noCache = true,
  }) {
    return _request.request(
      url,
      data: data,
      header: {
        if (header != null) ...header,
        if (!noCache && refreshCache) ...NetCache.refreshListHeader(),
        if (noCache) ...NetCache.noCacheHeader(),
      },
      timeout: timeout,
      contentType: contentType,
    );
  }
}
