//
// @author vay
// @email hxhvay@126.com
// @date 2020-05-10
//

import 'package:shared_preferences/shared_preferences.dart';

/// SharedPreferences工具类
class SpUtils {
  static SharedPreferences _sp;

  static init() async {
    if (_sp != null) {
      return;
    }
    _sp = await SharedPreferences.getInstance();
  }

  /// 不允许实例化
  SpUtils._();

  static _checkInit() {
    assert(_sp != null, "SpUtils isn't init success!");
  }

  static bool hasKey(String key) {
    Set keys = getKeys();
    return keys.contains(key);
  }

  static Set<String> getKeys() {
    _checkInit();
    return _sp.getKeys();
  }

  static get(String key) {
    _checkInit();
    return _sp.get(key);
  }

  static Future<bool> put<T>(String key, T value) {
    switch (T.toString()) {
      case "String":
        return putString(key, value as String);
      case "bool":
        return putBool(key, value as bool);
      case "int":
        return putInt(key, value as int);
      case "double":
        return putDouble(key, value as double);
      case "List<String>":
        return putStringList(key, value as List<String>);
    }
    return Future.value(false);
  }

  static getString(String key) {
    _checkInit();
    return _sp.getString(key);
  }

  static Future<bool> putString(String key, String value) {
    _checkInit();
    return _sp.setString(key, value);
  }

  static bool getBool(String key) {
    _checkInit();
    return _sp.getBool(key);
  }

  static Future<bool> putBool(String key, bool value) {
    _checkInit();
    return _sp.setBool(key, value);
  }

  static int getInt(String key) {
    _checkInit();
    return _sp.getInt(key);
  }

  static Future<bool> putInt(String key, int value) {
    _checkInit();
    return _sp.setInt(key, value);
  }

  static double getDouble(String key) {
    _checkInit();
    return _sp.getDouble(key);
  }

  static Future<bool> putDouble(String key, double value) {
    _checkInit();
    return _sp.setDouble(key, value);
  }

  static List<String> getStringList(String key) {
    return _sp.getStringList(key);
  }

  static Future<bool> putStringList(String key, List<String> value) {
    _checkInit();
    return _sp.setStringList(key, value);
  }

  static Future<bool> remove(String key) {
    _checkInit();
    return _sp.remove(key);
  }

  static Future<bool> clear() {
    _checkInit();
    return _sp.clear();
  }
}
