//
// @author vay
// @email hxhvay@126.com
// @date 2020-06-01
//

import 'package:flutter/material.dart';

/// 组件工具类
class WidgetUtils {
  WidgetUtils._();

  /// 空组件（空组件没有背景、并且不影响父组件的约束）
  static Widget empty() {
    return SizedBox.shrink();
  }

  /// 如果传入的组件为null，则返回一个空组件
  static Widget notNull(Widget source) {
    return source ?? empty();
  }

  /// 禁用跟随系统字体缩放
  ///
  /// 使用方式：
  /// ```
  /// MaterialApp(
  ///   home: core.textScaleDisable(HomePager()),
  ///   ...
  /// );
  /// ```
  static Widget textScaleDisable(Widget widget) {
    return MediaQuery(
      data: MediaQueryData.fromWindow(
        WidgetsBinding.instance.window,
      ).copyWith(
        textScaleFactor: 1,
      ),
      child: widget,
    );
  }
}
